@@ -12,13 +12,15 @@ Contents
 .. autosummary::
    :toctree: generated/
 
+   analyze_structure
    nanogen
-   nanogenui
+   NanoGen
 
 """
 from __future__ import absolute_import, division, print_function
 __docformat__ = 'restructuredtext en'
 
+from .analyze_structure import *
 from .nanogen import *
 from .nanogenui import NanoGen
 
